Locate the currently active R source file (in RStudio or from the –file command line argument) and run styler::style_file on it using a tidyverse style with 2-space indent.
Locate the currently active R source file (in RStudio or from the –file command line argument) and run styler::style_file on it using a tidyverse style with 2-space indent.